@@ -2,8 +2,16 @@
 
 pub use dioxus_core as core;
 
-#[cfg(feature = "hooks")]
-pub use dioxus_hooks as hooks;
+pub mod hooks {
+    #[cfg(feature = "hooks")]
+    pub use dioxus_hooks::*;
+
+    #[cfg(all(target_arch = "wasm32", feature = "web"))]
+    pub use dioxus_web::use_eval;
+
+    #[cfg(all(not(target_arch = "wasm32"), feature = "desktop"))]
+    pub use dioxus_desktop::use_eval;
+}
 
 #[cfg(feature = "router")]
 pub use dioxus_router as router;
@@ -14,12 +22,20 @@ pub use dioxus_ssr as ssr;
 #[cfg(feature = "web")]
 pub use dioxus_web as web;
 
+#[cfg(feature = "liveview")]
+pub use dioxus_liveview as liveview;
+
 #[cfg(feature = "desktop")]
 pub use dioxus_desktop as desktop;
 
 #[cfg(feature = "tui")]
 pub use dioxus_tui as tui;
 
+#[cfg(feature = "native-core")]
+pub use dioxus_native_core as native_core;
+#[cfg(feature = "native-core")]
+pub use dioxus_native_core_macro as native_core_macro;
+
 #[cfg(feature = "fermi")]
 pub use fermi;
 
@@ -29,10 +45,10 @@ pub mod events {
 }
 
 pub mod prelude {
+    pub use crate::hooks::*;
     pub use dioxus_core::prelude::*;
     pub use dioxus_core_macro::{format_args_f, inline_props, rsx, Props};
     pub use dioxus_elements::{GlobalAttributes, SvgAttributes};
-    pub use dioxus_hooks::*;
     pub use dioxus_html as dioxus_elements;
 
     #[cfg(feature = "router")]
