@@ -224,7 +224,7 @@ fn two_fragments_with_differrent_elements_are_differet() {
     );
 
     let (_create, changes) = dom.diff_lazynodes(left, right);
-    log::debug!("{:#?}", &changes);
+    log::trace!("{:#?}", &changes);
     assert_eq!(
         changes.edits,
         [
@@ -360,7 +360,7 @@ fn keyed_diffing_out_of_order() {
     });
 
     let (_, changes) = dom.diff_lazynodes(left, right);
-    log::debug!("{:?}", &changes);
+    log::trace!("{:?}", &changes);
     assert_eq!(
         changes.edits,
         [PushRoot { root: 7 }, InsertBefore { root: 5, n: 1 }]
@@ -546,7 +546,7 @@ fn keyed_diffing_additions_and_moves_on_ends() {
     });
 
     let (_, change) = dom.diff_lazynodes(left, right);
-    log::debug!("{:?}", change);
+    log::trace!("{:?}", change);
     assert_eq!(
         change.edits,
         [
@@ -579,7 +579,7 @@ fn keyed_diffing_additions_and_moves_in_middle() {
 
     // LIS: 4, 5, 6
     let (_, change) = dom.diff_lazynodes(left, right);
-    log::debug!("{:#?}", change);
+    log::trace!("{:#?}", change);
     assert_eq!(
         change.edits,
         [
@@ -616,7 +616,7 @@ fn controlled_keyed_diffing_out_of_order() {
 
     // LIS: 5, 6
     let (_, changes) = dom.diff_lazynodes(left, right);
-    log::debug!("{:#?}", &changes);
+    log::trace!("{:#?}", &changes);
     assert_eq!(
         changes.edits,
         [
@@ -653,7 +653,7 @@ fn controlled_keyed_diffing_out_of_order_max_test() {
     });
 
     let (_, changes) = dom.diff_lazynodes(left, right);
-    log::debug!("{:#?}", &changes);
+    log::trace!("{:#?}", &changes);
     assert_eq!(
         changes.edits,
         [
@@ -730,3 +730,29 @@ fn remove_list_nokeyed() {
         ]
     );
 }
+
+#[test]
+fn add_nested_elements() {
+    let vdom = new_dom();
+
+    let (_create, change) = vdom.diff_lazynodes(
+        rsx! {
+            div{}
+        },
+        rsx! {
+            div{
+                div{}
+            }
+        },
+    );
+
+    assert_eq!(
+        change.edits,
+        [
+            PushRoot { root: 1 },
+            CreateElement { root: 2, tag: "div" },
+            AppendChildren { many: 1 },
+            PopRoot {},
+        ]
+    );
+}
